@@ -7,7 +7,7 @@ use Carp qw[croak];
 
 use vars qw[$VERSION $DisablePerl $Untaint $Debug];
 
-$VERSION        = '0.36';
+$VERSION        = '0.40';
 $DisablePerl    = 0;
 $Untaint        = 0;
 $Debug          = 0;
@@ -580,6 +580,7 @@ sub _colon_sep {
     my $fh   = $self->fh;
 
     my %config;
+    local $_;
     while (<$fh>) {
         next if /^\s*#/;
         /^\s*(.*?)\s*:\s*(.*)/ or next;
@@ -657,12 +658,12 @@ sub _check_hash_and_assign {
         my $fh   = $self->fh;
 
         my %config;
-        while (<$fh>) {
+        local $_;
+        while ( <$fh>) {
             next if     /^\s*#/;
             next unless /^\s*(.*?)\s*=\s*(.*?)\s*$/;
 
             my ($k, $v) = ($1, $2);
-            my @v;
 
             ### multiple enries, but no shell tokens?
             if ($v=~ /,/ and $v !~ /(["']).*?,.*?\1/) {
@@ -672,7 +673,7 @@ sub _check_hash_and_assign {
                 ### only load once
                 require Text::ParseWords unless $loaded_tp++;
 
-                @v = Text::ParseWords::shellwords($v);
+                $config{$k} = [ Text::ParseWords::shellwords($v) ];
 
             } else {
                 $config{$k} = $v;
@@ -687,6 +688,7 @@ sub _check_hash_and_assign {
         my $fh   = $self->fh;
 
         my %config;
+        local $_;
         while (<$fh>) {
             next if     /^\s*#/;
             next unless /\s*(\S+)\s+(.*)/;
